package com.ruoyi.frequency.orderextensionrecord.service;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.common.page.PageResult;
import com.ruoyi.controller.req.OrderChangeRecordPageReq;
import com.ruoyi.frequency.orderextensionrecord.entity.OrderExtensionRecord;
import com.ruoyi.response.ResponseData;
import com.ruoyi.vo.UserVo;

import java.util.List;

/**
 * 订单延期记录Service接口
 * 
 * @author liwenlong
 * @date 2023-11-03
 */
public interface OrderExtensionRecordService extends IService<OrderExtensionRecord>
{
    /**
     * 查询订单延期记录
     * 
     * @param id 订单延期记录主键
     * @return 订单延期记录
     */
    public OrderExtensionRecord selectOrderExtensionRecordById(Long id);

    /**
     * 查询订单延期记录列表
     * 
     * @param orderExtensionRecord 订单延期记录
     * @return 订单延期记录集合
     */
    public List<OrderExtensionRecord> selectOrderExtensionRecordList(OrderExtensionRecord orderExtensionRecord);

    /**
     * 新增订单延期记录
     * 
     * @param orderExtensionRecord 订单延期记录
     * @return 结果
     */
    public int insertOrderExtensionRecord(OrderExtensionRecord orderExtensionRecord);

    /**
     * 修改订单延期记录
     * 
     * @param orderExtensionRecord 订单延期记录
     * @return 结果
     */
    public int updateOrderExtensionRecord(OrderExtensionRecord orderExtensionRecord);

    /**
     * 批量删除订单延期记录
     * 
     * @param ids 需要删除的订单延期记录主键集合
     * @return 结果
     */
    public int deleteOrderExtensionRecordByIds(Long[] ids,Integer delFalg);

    /**
     * 订单延期记录
     * @param req
     * @param userVo
     * @return
     */
    ResponseData<PageResult<Page<OrderExtensionRecord>>> orderExtensionRecordPage(OrderChangeRecordPageReq req, UserVo userVo);
}
